4.29. umbra.guerilla — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.29. umbra.guerilla

guerilla.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines various guerilla / monkey patching objects.
Others:
  Portions of the code by Guido Van Rossum: http://mail.python.org/pipermail/python-dev/2008-January/076194.html

## 4.29.1. Functions

`umbra.guerilla.` `attributeWarfare`(object)

  This decorator is used to alterate an object attribute using guerilla / monkey patching.

  Parameters: | object – Object to alterate. ( Object )
  Returns: | Object. ( Object )

`umbra.guerilla.` `baseWarfare`(name, bases, attributes)

  This definition adds any number of attributes to an existing class.

  Parameters: | name – Name. ( String ) bases – Bases. ( List ) attributes – Attributes. ( Dictionary )
  Returns: | Base. ( Object )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »